# flask-management

![flask-management Actions](https://api.meercode.io/badge/ponytailer/flask-management?type=ci-score&lastDay=14)

## How to use :

- simple command: `flaskapi your-project-name`

- choose your python version: `flaskapi your-project-name --python 3.7`

Inspired by `manage-fastapi`
